float4x4 proj;
float4x4 view;
float4x4 world;

texture tex;
float uv_left;
float uv_top;
float uv_width;
float uv_height;
float color_r;
float color_g;
float color_b;
float alpha;

sampler smp = sampler_state {
    texture = <tex>;
};


struct VS_IN {
    float3 pos : POSITION;
    float2 uv : TEXCOORD0;
};

struct VS_OUT {
    float4 pos : POSITION;
    float2 uv : TEXCOORD0;
};


// _VF[_
VS_OUT vs_main( VS_IN In ) {
    VS_OUT Out = (VS_OUT)0;

    Out.pos = mul( float4(In.pos, 1.0f), world );
    Out.pos = mul( Out.pos, view );
    Out.pos = mul( Out.pos, proj );
    Out.uv = In.uv * float2(uv_width, uv_height) + float2(uv_left, uv_top);

    return Out;
}


// sNZVF[_
float4 ps_main(VS_OUT In) : COLOR0 {
    float4 color = tex2D( smp, In.uv );
    color.r *= color_r;
    color.g *= color_g;
    color.b *= color_b;
    color.a *= alpha;
    return color;
}


technique Tech {
    pass p0 {
        AlphaBlendEnable = true;
        SrcBlend = SRCALPHA;
        DestBlend = INVSRCALPHA;
        ZEnable = true;
        ZWriteEnable = true;

        VertexShader = compile vs_2_0 vs_main();
        PixelShader = compile ps_2_0 ps_main();
    }
    pass p1 {
        AlphaBlendEnable = true;
        SrcBlend = SRCALPHA;
        DestBlend = INVSRCALPHA;
        ZEnable = true;
        ZWriteEnable = false;

        VertexShader = compile vs_2_0 vs_main();
        PixelShader = compile ps_2_0 ps_main();
    }
    pass p2 {
        AlphaBlendEnable = true;
        SrcBlend = SRCALPHA;
        DestBlend = INVSRCALPHA;
        ZEnable = false;
        ZWriteEnable = false;

        VertexShader = compile vs_2_0 vs_main();
        PixelShader = compile ps_2_0 ps_main();
    }
    pass p3 {
        AlphaBlendEnable = true;
        SrcBlend = SRCALPHA;
        DestBlend = INVSRCALPHA;
        ZEnable = false;
        ZWriteEnable = false;

        VertexShader = compile vs_2_0 vs_main();
        PixelShader = compile ps_2_0 ps_main();
    }
}
